using System;
using System.Web.UI;
using System.Web.UI.WebControls;

using System.IO;
using System.Data;
using System.Data.SqlClient;
using System.Configuration;

public partial class CS : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        gvCustomers.DataSource = this.GetData("SELECT CustomerID, City FROM Customers");
        gvCustomers.DataBind();

        gvOrders.DataSource = this.GetData("SELECT OrderID, CustomerID FROM Orders");
        gvOrders.DataBind();
    }

    private DataTable GetData(string query)
    {
        string constr = ConfigurationManager.ConnectionStrings["constr"].ConnectionString;
        using (SqlConnection con = new SqlConnection(constr))
        {
            using (SqlDataAdapter sda = new SqlDataAdapter(query, con))
            {
                using (DataTable dt = new DataTable())
                {
                    sda.Fill(dt);
                    return dt;
                }
            }
        }
    }

    protected void OnPaging(object sender, GridViewPageEventArgs e)
    {
        GridView gridView = (GridView)sender;
        gridView.PageIndex = e.NewPageIndex;
        gridView.DataBind();
    }

    protected void ExportToExcel(object sender, EventArgs e)
    {
        Response.Clear();
        Response.Buffer = true;
        Response.AddHeader("content-disposition", "attachment;filename=GridViewExport.xls");
        Response.Charset = "";
        Response.ContentType = "application/vnd.ms-excel";

        using (StringWriter sw = new StringWriter())
        {
            HtmlTextWriter hw = new HtmlTextWriter(sw);

            this.PrepareForExport(gvCustomers);
            this.PrepareForExport(gvOrders);

            Table table = new Table();

            TableRow row1 = new TableRow();

            TableCell cell1 = new TableCell();
            cell1.Controls.Add(gvCustomers);
            row1.Cells.Add(cell1);

            TableCell cell2 = new TableCell();
            cell2.Text = "&nbsp;";

            TableCell cell3 = new TableCell();
            cell3.Controls.Add(gvOrders);

            if (rbPreference.SelectedValue == "2")
            {
                row1.Cells.Add(cell2);
                row1.Cells.Add(cell3);
                table.Rows.Add(row1);
            }
            else
            {
                TableRow tr2 = new TableRow();
                tr2.Cells.Add(cell2);

                TableRow tr3 = new TableRow();
                tr3.Cells.Add(cell3);

                table.Rows.Add(row1);
                table.Rows.Add(tr2);
                table.Rows.Add(tr3);
            }
            table.RenderControl(hw);

            //style to format numbers to string.
            string style = @"<style> .textmode { mso-number-format:\@; } </style>";
            Response.Write(style);
            Response.Output.Write(sw.ToString());
            Response.Flush();
            Response.End();
        }
    }

    protected void PrepareForExport(GridView gridView)
    {
        gridView.AllowPaging = Convert.ToBoolean(rbPaging.SelectedItem.Value);
        gridView.PagerSettings.Visible = false;
        gridView.DataBind();

        foreach (GridViewRow row in gridView.Rows)
        {
            //Apply text style to each Row.
            row.Attributes.Add("class", "textmode");
        }
    }

    public override void VerifyRenderingInServerForm(Control control)
    {
        /* Verifies that the control is rendered */
    }
}